@@ -481,8 +481,7 @@ summary.outbreaker_chains <- function(object, burnin = 0, group_cluster = NULL,
   
   ## function to get most frequent item
   f1 <- function(x) {
-    if(length(table(x)) > 0) as.integer(names(sort(table(x), decreasing = TRUE)[1]))
-    else NA
+    as.integer(names(sort(table(x, exclude = NULL), decreasing = TRUE)[1]))
   }
   out$tree$from <- apply(alpha, 2, f1)
   out$tree$to <- seq_len(ncol(alpha))
@@ -496,6 +495,7 @@ summary.outbreaker_chains <- function(object, burnin = 0, group_cluster = NULL,
     (sort(table(x, exclude = NULL), decreasing = TRUE)/length(x))[1]
   }
   out$tree$support <- apply(alpha, 2, f2)
+  out$tree$support[is.na(out$tree$from)] <- NA
   
   ## Import probability ##
   f3 <- function(x) {
